# CreateOrderResponseWriteOffStatus

The status of the write-off.

## Enum

* `SUCCESS` (value: `'Success'`)

* `FAILED` (value: `'Failed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


